[Mlir-commits] [mlir] 6761dd7 - [MLIR][Presburger] fix the names of some tests (NFC)

Arjun P llvmlistbot at llvm.org
Mon Mar 21 08:25:34 PDT 2022


Author: Arjun P
Date: 2022-03-21T15:23:37Z
New Revision: 6761dd7d0a7f4882e2f79cf10052652622a6d284

URL: https://github.com/llvm/llvm-project/commit/6761dd7d0a7f4882e2f79cf10052652622a6d284
DIFF: https://github.com/llvm/llvm-project/commit/6761dd7d0a7f4882e2f79cf10052652622a6d284.diff

LOG: [MLIR][Presburger] fix the names of some tests (NFC)

Added: 
    

Modified: 
    mlir/unittests/Analysis/Presburger/IntegerPolyhedronTest.cpp
    mlir/unittests/Analysis/Presburger/SimplexTest.cpp

Removed: 
    


################################################################################
diff  --git a/mlir/unittests/Analysis/Presburger/SimplexTest.cpp b/mlir/unittests/Analysis/Presburger/SimplexTest.cpp
index 0edc5f0da019f..a66f1fefb3256 100644
--- a/mlir/unittests/Analysis/Presburger/SimplexTest.cpp
+++ b/mlir/unittests/Analysis/Presburger/SimplexTest.cpp
@@ -389,7 +389,7 @@ TEST(SimplexTest, isMarkedRedundantTiledLoopNestConstraints) {
   EXPECT_FALSE(simplex.isMarkedRedundant(5));
 }
 
-TEST(Simplextest, pivotRedundantRegressionTest) {
+TEST(SimplexTest, pivotRedundantRegressionTest) {
   Simplex simplex(2);
   simplex.addInequality({-1, 0, -1}); // x <= -1.
   unsigned snapshot = simplex.getSnapshot();


        


More information about the Mlir-commits mailing list
diff  --git a/mlir/unittests/Analysis/Presburger/IntegerPolyhedronTest.cpp b/mlir/unittests/Analysis/Presburger/IntegerPolyhedronTest.cpp
index f85c4a81a1cd9..46f9f3e568044 100644
--- a/mlir/unittests/Analysis/Presburger/IntegerPolyhedronTest.cpp
+++ b/mlir/unittests/Analysis/Presburger/IntegerPolyhedronTest.cpp
@@ -50,7 +50,7 @@ static void dump(ArrayRef<int64_t> vec) {
 ///   non-empty lexmin.
 ///
 ///   If hasSample is false, check that findIntegerSample returns None and
 ///   getIntegerLexMin returns Empty.
 ///
 /// If fn is TestFunction::Empty, check that isIntegerEmpty returns the
 /// opposite of hasSample.
@@ -72,7 +72,7 @@ static void checkSample(bool hasSample, const IntegerPolyhedron &poly,
 
       EXPECT_TRUE(maybeLexMin.isEmpty());
       if (maybeLexMin.isBounded()) {
-        llvm::errs() << "getIntegerLexMin gave sample: ";
+        llvm::errs() << "findIntegerLexMin gave sample: ";
         dump(*maybeLexMin);
       }
     } else {
@@ -1051,7 +1051,7 @@ void expectNoRationalLexMin(OptimumKind kind, const IntegerPolyhedron &poly) {
   EXPECT_EQ(poly.findRationalLexMin().getKind(), kind);
 }
 
-TEST(IntegerPolyhedronTest, getRationalLexMin) {
+TEST(IntegerPolyhedronTest, findRationalLexMin) {
   expectRationalLexMin(
       parsePoly("(x, y, z) : (x + 10 >= 0, y + 40 >= 0, z + 30 >= 0)"),
       {{-10, 1}, {-40, 1}, {-30, 1}});
@@ -1123,7 +1123,7 @@ void expectNoIntegerLexMin(OptimumKind kind, const IntegerPolyhedron &poly) {
   EXPECT_EQ(poly.findRationalLexMin().getKind(), kind);
 }
 
-TEST(IntegerPolyhedronTest, getIntegerLexMin) {
+TEST(IntegerPolyhedronTest, findIntegerLexMin) {
   expectIntegerLexMin(parsePoly("(x, y, z) : (2*x + 13 >= 0, 4*y - 3*x - 2  >= "
                                 "0, 11*z + 5*y - 3*x + 7 >= 0)"),
                       {-6, -4, 0});
@@ -50,7 +50,7 @@ static void dump(ArrayRef<int64_t> vec) {
 ///
 ///   If hasSample is false, check that findIntegerSample returns None and
-///   getIntegerLexMin returns Empty.
+///   findIntegerLexMin returns Empty.
 ///
 /// If fn is TestFunction::Empty, check that isIntegerEmpty returns the
